%define apache_version 1.3.33
%define modssl_version 2.8.22

Summary:     Apache Interface to OpenSSL
Name:        mod_ssl
Version:     %{modssl_version}
Release:     25.pp
License:     BSD-style, ModSSL
Group:       System Environment/Daemons
Source0:     http://www.modssl.org/source/%{name}-%{version}-%{apache_version}.tar.gz
Source1:     %{name}.conf
Source2:     ssl-vhosts.conf
Patch0:      mod_ssl-openssl-version.patch
URL:         http://www.modssl.org/
Buildroot:   /var/tmp/%{name}-root
Vendor:      Ralf S. Engelschall <rse@engelschall.com>
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Requires:    apache = %{apache_version} apache.pp openssl097 make
Provides:    %{name}.pp
Prereq:      /bin/bash
BuildPrereq: gcc >= 2.96 /usr/bin/perl /bin/mkdir /usr/bin/make
BuildPrereq: /usr/bin/install /usr/sbin/apxs /bin/sed openssl097-devel
BuildPrereq: glibc-devel apache-devel = %{apache_version} mm-devel
ExclusiveOS: linux

%description
mod_ssl provides provides strong cryptography for the Apache 1.3
webserver via the Secure Sockets Layer (SSL v2/v3) and Transport
Layer Security (TLS v1). It is based on the SSL/TLS toolkit OpenSSL
and supports all SSL/TLS related functionality, including RSA and
DSA/DH cipher support, X.509 CRL checking, etc. Additionally it
provides special Apache related facilities like DBM and shared
memory based inter-process SSL session caching, per-URL SSL session
renegotiations, DSO support, etc.


%package manual
Summary:     Documentation for the SSL module.
Group:       Documentation
Requires:    apache-manual = %{apache_version} %{name} = %{modssl_version}
Provides:    %{name}-manual.pp

%description manual
The %{name}-manual package contains the complete manual and programming
reference for the SSL module. It requires apache-manual to be installed.
It can also be found on the web at http://www.modssl.org/.


%prep
%setup -q -n %{name}-%{version}-%{apache_version}
%patch0 -p1


%build
export CFLAGS="$RPM_OPT_FLAGS"
export LIBS="-lpthread"
export EAPI_MM="SYSTEM"
./configure \
	--with-apxs=/usr/sbin/apxs
cat pkg.sslmod/Makefile | \
	sed -e 's+SSL_CFLAGS=+SSL_CFLAGS=-I/usr/include/gdbm -DSSL_SDBM -DSSL_EXPERIMENTAL -DSSL_VENDOR -I/usr/kerberos/include+g' > tmp_file
mv tmp_file pkg.sslmod/Makefile
make
cd pkg.addon
apxs -c mod_define.c
cd ..


# Do not strip, only compress documentation
%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt
mkdir -p $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crl
mkdir -p $RPM_BUILD_ROOT/etc/httpd/conf/ssl.key
mkdir -p $RPM_BUILD_ROOT/etc/httpd/conf/modules
mkdir -p $RPM_BUILD_ROOT/usr/lib/apache
mkdir -p $RPM_BUILD_ROOT/var/httpd/htdocs/manual/mod/mod_ssl
install -m 755 pkg.sslmod/libssl.so $RPM_BUILD_ROOT/usr/lib/apache
install -m 755 pkg.addon/mod_define.so $RPM_BUILD_ROOT/usr/lib/apache
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/etc/httpd/conf/modules
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/etc/httpd/conf/modules/mod_ssl.conf.default
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/etc/httpd/conf
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/etc/httpd/conf/ssl-vhosts.conf.default

rm -f pkg.ssldoc/*.patch pkg.ssldoc/Makefile*
cp -r pkg.ssldoc/* $RPM_BUILD_ROOT/var/httpd/htdocs/manual/mod/mod_ssl
cp pkg.addon/mod_define.html $RPM_BUILD_ROOT/var/httpd/htdocs/manual/mod

install -m 644 pkg.sslcfg/Makefile.crt $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt/Makefile
install -m 644 pkg.sslcfg/*.CRT $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt
install -m 644 pkg.sslcfg/ca-bundle.crt $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt
install -m 644 pkg.sslcfg/snakeoil*.crt $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt
install -m 644 pkg.sslcfg/server.crt $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crt

install -m 644 pkg.sslcfg/Makefile.crl $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crl/Makefile
install -m 644 pkg.sslcfg/*.CRL $RPM_BUILD_ROOT/etc/httpd/conf/ssl.crl

install -m 644 pkg.sslcfg/*.KEY $RPM_BUILD_ROOT/etc/httpd/conf/ssl.key
install -m 640 pkg.sslcfg/snakeoil*.key $RPM_BUILD_ROOT/etc/httpd/conf/ssl.key
install -m 640 pkg.sslcfg/server.key $RPM_BUILD_ROOT/etc/httpd/conf/ssl.key


%post
make -C /etc/httpd/conf/ssl.crt clean > /dev/null 2>&1
make -C /etc/httpd/conf/ssl.crt > /dev/null 2>&1
make -C /etc/httpd/conf/ssl.crl clean > /dev/null 2>&1
make -C /etc/httpd/conf/ssl.crl > /dev/null 2>&1


%preun
make -C /etc/httpd/conf/ssl.crt clean > /dev/null 2>&1
make -C /etc/httpd/conf/ssl.crl clean > /dev/null 2>&1


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root)
%doc ANNOUNCE CHANGES CREDITS INSTALL* LICENSE NEWS README*
%dir /etc/httpd/conf/ssl.crt
%config(noreplace) /etc/httpd/conf/ssl.crt/*
%dir /etc/httpd/conf/ssl.crl
%config(noreplace) /etc/httpd/conf/ssl.crl/*
%dir %attr(750,root,www) /etc/httpd/conf/ssl.key
%config(noreplace) %attr(640,root,www) /etc/httpd/conf/ssl.key/*
%config /etc/httpd/conf/modules/mod_ssl.conf
%config /etc/httpd/conf/ssl-vhosts.conf
/etc/httpd/conf/*.default
/etc/httpd/conf/modules/*.default
/usr/lib/apache/*

%files manual
%defattr(-,root,root)
%dir /var/httpd/htdocs/manual/mod/mod_ssl
/var/httpd/htdocs/manual/mod/mod_ssl/*
/var/httpd/htdocs/manual/mod/*.html


%changelog
* Wed May 04 2005 peter.pramberger@member.fsf.org
- minor bugfix in mod_ssl.conf

* Tue Nov 02 2004 peter.pramberger@member.fsf.org
- new version 2.8.22

* Fri May 14 2004 peter.pramberger@member.fsf.org
- new version 2.8.17

* Sun Nov 02 2003 peter.pramberger@member.fsf.org
- new version 2.8.16

* Fri Oct 03 2003 peter.pramberger@member.fsf.org
- minor bug fixes to spec file
- install dummy certificate and key

* Fri Aug 22 2003 peter.pramberger@member.fsf.org
- new version 2.8.15

* Wed May 07 2003 peter.pramberger@member.fsf.org
- compiled for RH73

* Thu Apr 17 2003 peter.pramberger@member.fsf.org
- new version 2.8.14 (security bugfixes)

* Tue Nov 05 2002 peter.pramberger@member.fsf.org
- new version 2.8.12

* Mon Aug 19 2002 peter.pramberger@member.fsf.org
- linked against openssl version 0.9.6g (security bugfixes)

* Thu Aug 01 2002 peter.pramberger@member.fsf.org
- new version 2.8.10 for apache 1.3.26
- linked against openssl version 0.9.6e (security bugfixes)

* Sat Nov 10 2001 peter.pramberger@member.fsf.org
- new version 2.8.5
- new apache version 1.3.22

* Mon Oct 08 2001 peter.pramberger@member.fsf.org
- created

